#
# spec file for package gnome-maps
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-maps
Version:        48.1
Release:        1.1
Summary:        Maps Application for GNOME
License:        Apache-2.0 AND CC-BY-3.0 AND GPL-2.0-or-later AND BSD-3-Clause AND ISC AND MIT
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Maps
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
# Needed for typelib() Requires
BuildRequires:  gobject-introspection
#
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.40.0
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(folks) >= 0.10.0
BuildRequires:  pkgconfig(gee-0.8) >= 0.16.0
BuildRequires:  pkgconfig(geoclue-2.0) >= 0.12.99
BuildRequires:  pkgconfig(geocode-glib-2.0) >= 3.15.2
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gjs-1.0) >= 1.69.2
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.1
BuildRequires:  pkgconfig(gtk4) >= 3.22.0
# Needed for test run
BuildRequires:  pkgconfig(gweather4) >= 3.90.0
#
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libportal)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(rest-1.0) >= 0.7.90
BuildRequires:  pkgconfig(shumate-1.0) >= 1.4.alpha
Recommends:     dbus(org.freedesktop.GeoClue2)

%description
Maps is a maps application for GNOME 3. It allows viewing street maps from
OpenStreetMaps and satellite imagery from Mapbox. You can also get directions
for your journeys, whether on foot, by bike, or by car.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%check
%meson_test

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
# There is no devel package, so at this moment also no need to keep gir and so files
rm %{buildroot}%{_datadir}/gnome-maps/gir-1.0/GnomeMaps-1.0.gir
rm %{buildroot}%{_libdir}/%{name}/libgnome-maps.so

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Maps.appdata.xml
%{_datadir}/applications/org.gnome.Maps.desktop
%{_datadir}/dbus-1/services/org.gnome.Maps.service
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/org.gnome.Maps*
%{_datadir}/glib-2.0/schemas/org.gnome.Maps.gschema.xml
%{_libdir}/%{name}/libgnome-maps.so.0*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/girepository-1.0
%{_libdir}/%{name}/girepository-1.0/GnomeMaps-1.0.typelib

%files lang -f %{name}.lang

%changelog
* Sat Mar 22 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.1:
  + Fix correctly calculating timezone offsets in MOTIS results, so
    timestamps gives correct values for daylight savings time.
  + Updated translations.
* Sat Mar 15 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Updated translations.
* Sat Mar  1 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.rc:
  + Update OSM edit POI defintions
  + Update highway shields from OpenStreetMap-Americana
  + Use Transitous for public transit in Finland, as the old
    OTP1-based Digitransit API is being deprecated
  + Show stairs instructions for walking directions with Transitous
  + Updated translations.
* Thu Jan 30 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + Redesigned user location marker, using system accent color.
  + Redesigned/improved rendering of route markers and public
    transit route itineraries.
  + Updated translations.
* Thu Jan 30 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.alpha2:
  + Define release artifact path as a global variable in CI
- Changes from version 48.alpha:
  + Moved the Transitous support to use the new MOTIS v2 API
  + Refreshed headerbar icons for layers and favorites menu buttons
  + Added animation to favorite star when favoring a place
  + Use AdwSpinner widgets for all spinners
  + Close sidebar when pressing Esc
  + Updated screenshots to reflect new map theme, public transit
    support, and dark mode
  + Use an AdwToggleGroup widget for the routing mode switcher
  + Redesigned POI edit dialog
  + Updated translations.
* Thu Jan 30 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.4:
  + Fix parsing of geo: URIs.
  + Fix departure and arrival location names when searching by
    arrival time when using Transitous/MOTIS2.
* Sat Jan  4 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.3:
  + Switch the Transitous public transit support to the new MOTIS
    API v2
* Sat Nov 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Fix a bug where the zoom level was reset to 0 when opening a
    geo: URI not specifying an explicit zoom level.
  + Updated translatations.
* Fri Oct 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Fix leaking map bubble popover widgets
  + Fix showing public transit operator names containing characters
    needing markup-escaping
  + Updated translatations.
* Fri Sep 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + Fix issue with sometimes bad contrasting public transit route
    lines.
  + Fix orientation of "fish head"-shaped highway shields.
  + Add additional public transit mode icons, and also use taxi
    icon for taxi stations.
  + Updated translations.
* Sat Aug 31 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Support Transitous for public transit routing
  + Update POI definitions
  + Update highway shields from OSM Americana
  + Don't grab focus on search entry when pressing modifier keys
  + Fix build with -Dvector_renderer=false
  + Allow building with C++
  + Fix crash in MapSource
  + Add documentation for the GTK inspector page
  + Fix compilation warnings
  + Use the vector by default, and remove the old raster tiles
  + Remove the "What's here" menu item, as we now have clickable
    POIs
  + Stop using the downloaded service file, as it's not needed for
    raster tiles now that the vector style embeds a map source, and
    instead bundle defintions for public transit providers
  + Use zoom parameter from geo: URIs when available
  + Support dark mode when drawing public transit routes on the map
  + Unselect previously selected place when clicking on the
    background
  + Speed up "zoom to" animations
  + Show brand logos from Wikidata for POIs when available
  + Show place type icon and in place type in bubbles for POIs
  + Port more dialogs to use libadwaita dialogs
  + Add missing mnemonics for menu items
  + Various a11y improvements
  + Add playground icons :)
  + Properly show 12/24 hour format based on system setting when
    selecting time for public transit routing when running as
    Flakpak
  + Set Window icon, used by some WMs/DEs
  + Updated translations.
* Mon May 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.11:
  + Fix crash on startup when unnamed favorites where previously
    saved.
  + Don't show OSM edit dialog if the user previously reclined
    signing in.
  + Don't show stored routes in the search results when searching
    for destinations.
- changes from version 46.10:
  + Due to a typo in the version number in the metadata for 46.0
    (being 46.9) make this release version number 46.10
  + Fix current location marker not moving when updating location.
  + Updated translations.
* Mon May 13 2024 dimstar@opensuse.org
- Update to version 46.11:
  * Release 46.11
  * placeListRow: Use fallback when place has no title
  * Update Hindi translation
  * Update Brazilian Portuguese translation
  * Update Portuguese translation
  * mapView: Check the signed in status after showing the OSM account dialog
  * placeButtons: Check the signed in status after showing the OSM account dialog
  * Update Greek translation
  * placeEntry: Fix filtering out stored routes for routing entries
  * Post-release version bump
  * Release 46.10
  * shields: Fix shields with OMT update
  * place: Make location a GObject property
  * Update Kabyle translation
  * meson: Bump next version to 46.10
  * appdata: Fix typo in release version number
  * Post-release version bump
* Sat Mar 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Fix routes covering user location marker.
  + Update project link in DOAP file.
  + Updated translations.
* Sat Mar 16 2024 dimstar@opensuse.org
- Update to version 46.0:
  * Release 46.9
  * Fix link
  * Update Korean translation
  * Add Kabyle translation
  * Update Polish translation
  * Update Occitan translation
  * Update POTFILES.in
  * Update Latvian translation
  * Update Italian translation
  * mapView: Put route layer below position marker layer
  * Update Danish translation
  * Update Russian translation
  * doap: Change wiki link to apps.gnome.org
  * appdata: Add contribute URL
  * Update Swedish translation
  * Update Russian translation
  * Update Hungarian translation
  * appdata: Add 45.5 release
  * Post-release version bump
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Lots of updates to the map style.
  + Fix parsing OSM object URLs with trailing slashes.
  + Updated translations.
- Add pkgconfig(librsvg-2.0) and pkgconfig(json-glib-1.0)
  BuildRequires: new dependencies.
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Redesigned zoom controls inspired by the Loupe image viewer.
  + Support for OpenTripPlanner v2 GraphQL for public transit
    routing.
  + Redeigned OSM account dialog, using Adwaita widgets.
  + Simplified/refactored more flexible storage format for the
    place store cache.
  + Fixed a bug preventing the POI browser showing in some cases.
  + Updated translations.
- Convert to source service for easier updating.
* Fri Feb 16 2024 Lubos Kocman <lubos.kocman@suse.com>
- Update license based on legaldb review
* Mon Dec  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2:
  + Fixed triggering a extranous reload of the trip query in the
    case the user has already filled in query points
  + Updated translations.
* Sat Oct 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Add more validation of transit plugin parameters
  + Fix showing missing nearby POIs when browsing in some cases
  + Set lower timeout when downloading service file
  + Fix searching for recent routes
  + Updated translations.
* Sat Sep 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Hide the experimental vector map toggle if libshumate is
    compiled without vector support.
  + Fix POI browser category labels showing translated strings.
  + Updated translations.
* Sat Sep  2 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.rc:
  + Enabled experimental vector-based map.
  + Update OSM edit POI definition.
  + Increase sidebar width to fit longer translated strings.
  + Updated translations.
* Fri Aug 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Use Adw.OverlaySplitView for the routing sidebar. This enables
    better narrow screen size adaptiveness and using touch gestures
    to open the sidebar.
  + Always show phone numbers as links when sandboxed (e.g.
    Flatpak).
  + Re-enable animations when going to new places and showing
    routes.
  + Use toasts for the OSM zoom in and location service dialogs.
  + Restrict to using only supported languages for the GraphHopper
    geocoding (search) service.
- Add pkgconfig(libportal) BuildRequires: New dependency.
* Fri Aug 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Implemented POI explore UI
  + Move zoom control buttons (back) to overlay
  + Add rotation button with ability to reset rotation
  + Make use of Adw.Toast for showing simple messages
  + Update screenshots
  + Add support for auth header in OpenTripPlanner plugin
- Drop gnome-maps-fix-dependency.patch: Still valid, but no longer
  needed.
* Fri Aug 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.4:
  + Fix for potential security issue.
  + Restrict GraphHopper geocoder to supported languages.
* Sun Jul  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.3:
  + Add support for auth headers in the OpenTripPlanner plugin.
  + Updated translations.
* Fri May 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Show thumbnails for places with a linked Wikidata entry with a
    title image, but that has no linked Wikipedia articles
  + Show the correct rotation of the user location marker when
    there is a heading (Geoclue indicating motion), in case the map
    view is rotated
  + Updated translations.
* Fri Apr 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Disable animations also on zoom-to-fit and when selecting
    itinerary point for public transit routes, to avoid tile server
    throttling.
  + Fix the "Send to" dialog which was broken in the case when
    there are external apps supporting geo: links.
  + Updated translations.
* Sat Mar 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0 (boo#1216184, boo#1217240):
  + Disable the go-to animation to avoid getting throttled by the
    tile server.
  + Updated translations.
* Sun Mar  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated POI definitions for OpenStreetMap editing
  + Center text in the location service dialog
  + Tweak header captilization and ellipsation for tooltips and
    menu items
  + Use proper suggestions style for search result lists
  + Add nightly builds for AArch64
  + Updated translations.
- Drop explicit typelib(GtkClutter) = 1.0 and
  typelib(GeocodeGlib) = 1.0 Requires: No longer needed.
* Wed Feb 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Prevent the scale to cover the sidebar when the window is
    narrow
  + Fix keyboard navigation of search results (regression from the
    GTK 4 port)
  + Style fixes of the sidebar border
  + Make the "export as image" dialog work on phones
  + Updated translations.
- Changes from version 44.alpha:
  + Fix excessive margins in place bubbles
  + Fix adaptive mode detection when maximized
  + Fix broken long-press to bring up the context menu on touch
    screens
  + Fixing various issues left after the GTK 4 port
  + Fix setting adaptive narrow (phone) mode on first launch on
    portrait displays
  + Fix dragging-and-dropping route entris in the sidebar
  + Fix opening shapelayer files when dragged-and-dropped onto the
    main window
  + Fix selecting turnpoint instructions showing the position of
    the instruction on the map
  + Fix local tiles (using the --local command-line option)
  + Fix location service dialog
  + Fix send-to dialog
  + Fix user location accuracy marker positioning
  + Implement support for getting thumbnails and Wikipedia article
    extracts from Wikidata
  + Updated translations.
- Drop gnome-maps-icu72.patch: Fixed upstream.
* Wed Feb  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.4:
  + Prevent the scale to cover the sidebar when the window is
    narrow.
* Sat Jan  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.3:
  + Fix blurry shape layers on zoom.
  + Fix user location accuracy marker positioning.
  + Various other bug fixes.
  + Updated translations.
* Fri Dec  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Fix excessive margins in place bubbles.
  + Fix adaptive mode detection when maximized.
  + Fix broken long-press to bring up the context menu on touch
    screens.
  + Updated translations.
* Fri Oct 28 2022 Michael Gorse <mgorse@suse.com>
- Add gnome-maps-icu72.patch: fix comparisons in time tests
  (glgo#GNOME/gnome-maps!261).
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Fixing various issues left after the GTK 4 port.
  + Fix setting adaptive narrow (phone) mode on first launch on
    portrait displays.
  + Fix dragging-and-dropping route entris in the sidebar.
  + Fix opening shapelayer files when dragged-and-dropped onto the
    main window.
  + Fix selecting turnpoint instructions showing the position of
    the instruction on the map.
  + Fix local tiles (using the --local command-line option).
  + Fix location service dialog.
  + Fix send-to dialog.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Remove build-dependency on GTK3.
  + Don't install tests gresource.
  + Updated translations.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
- Add appstream-glib and desktop-file-utils BuildRequires, validate
  appdata and desktop files during build.
- Add gnome-maps-fix-dependency.patch: Fix upstream dodo when
  setting dependency for libshumate.
* Sun Sep  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + Use Adwaita about dialog
  + Various UI cleanups, tweaks, and fixes
  + Switch OSM edit authorization to use OAuth 2
  + Update POI definitions for OSM editing
  + Updated translations.
- Drop pkgconfig(champlain-0.12) BuildRequires: No longer used, nor
  needed since the port to gtk4/libshumate.
* Thu Sep  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- GNOME Maps uses a gi dep syntax that is not yet understood by the
  dep scanner, thus add explicit Requires on typelib(GeocodeGlib)
  and typelib(GtkClutter),
* Mon Aug 22 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.beta:
  + Port to GTK 4 and libshumate.
  + Port to use libsoup 3.
- Adjust BuildRequires for upstream changes:
  + Drop pkgconfig(gtl3.0), pkgconfig(libndy-1)pkgconfig(rest-0.7),
    pkgconfig(geocode-glib-1.0)
  + Add pkgconfig(gtk4), pkgconfig(liadwaita-1),
    pkgconfig(rest-1.0),pkgconfig(geocode-glib-2.0),
    pkgconfig(shumate-1.0)
* Thu Jul  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.alpha:
  + Remove network check (always assume network is available).
  + Remove check-in support (as no GOA backends support this
    anymore).
  + Use external browser to authorize OSM account for editing.
  + Add checkbox to select the visibility of the scale.
  + Migrate code to use ES 6 modules.
  + Tune location bias scale parameter for the Photon geocoder.
  + Updated translations.
* Sun Jul  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.3:
  + Fix setting the correct month in the public transit time
    settings.
  + Fix a crash on exit.
  + Updated translations.
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + Fix using Ukrainian address format for addresses in Ukraine.
  + Updated translations.
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.1:
  + Update GWeather dependency to version 4.
  + Update the Resrobot public transit plugin to use the v2.1 API.
  + Don't optimize away keep left/right instructions for
    turn-by-turn routes.
  + Updated translations.
  - Replace pkgconfig(gweather-3.0) BuildRequires with
    pkgconfig(gweather4), following upstream changes.
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Save visibility of the scale in gsettings so it's remembered
    between runs
  + Update OSM POI definitions for OSM editing
  + Correctly set the initially selected date in the calendar
    widget for public transit routing, so that the date is always
    set to today when first selecting a date, even if Maps was
    started on an earlier day
  + Fix some incositencies when showing times for public transit
    itineraries
  + Update appdata screenshots
  + Use tabular numbers for time labels in the public transit
    itinerary views to keep things tidily lined up vertically
  + Updated translations.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Fix build with Meson 0.60+
  + Update required libhandy version
  + Use the location portal when sandboxed
  + Only use location bias when searching on high zoom levels, to
    work around problems with finding some locations (such as
    cities) with the Photon search API
  + Fix shortcuts overlay for development builds
  + Support alternative OpenStreetMap location URLs format in the
    search bar
  + Updated translations.
- Drop def20cbb26e59e5023fe157e691de48d7afe7210.patch: Fixed
  upstream.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha:
  + Add more fine-tuned initial zoom levels for more place types.
  + Add support for maps: URIs, DBus action, and command line
    option to initiate a search.
  + Show icons for u-turns in turn-by-turn routing.
  + Add dual-installation support (with devel icon for nightly).
  + Implement support for the new "prefer dark style" setting.
  + Improvements to appdata metadata.
  + Updated translations.
- Rebase def20cbb26e59e5023fe157e691de48d7afe7210.patch, use
  upstream commit.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.4:
  + Fix build with Meson 0.60+
  + Updated translations.
- Drop def20cbb26e59e5023fe157e691de48d7afe7210.patch: Fixed
  upstream.
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add def20cbb26e59e5023fe157e691de48d7afe7210.patch: Fix build
  with meson 0.61 and newer. Backported to apply on stable version.
* Sun Dec  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Updated translations.
* Sat Oct 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Updated translations.
* Sat Sep 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + State hardware support in appdata.
  + Updated translations.
* Sat Sep 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc:
  + Updated OSM POI types for editing.
  + Refine usage of shopping cart icon in search result to be used
    only for supermarket-like places.
  + Updated screenshots to reflect the switch to osm.org tiles.
  + Updated translations.
* Sat Sep 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Build librest for development Flatpaks.
  + Build ical from the 3.0 branch for development Flakpaks.
  + Update donation and wiki web links in appdata.
  + Updated translations.
* Sat Sep 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.alpha:
  + Fix regression when signing in for OSM editing.
  + Updated translations.
* Sat Sep 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.5:
  + Updated translations.
* Fri Aug 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.4:
  + Update donation and wiki web links in appdata.
* Sat Jul 10 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.3:
  + Fix regression when signing in for OSM editing.
  + Updated translations.
* Fri Jun  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Disable keyboard shortcuts to switch map styles when there's no
    aerial tiles defined
  + Fix a crash when starting up with last-used map type being
    aerial and no aerial tiles are defined
  + Increase place bubble max width to allow for longer translated
    strings for the "Directions" button
  + Fix warning from GtkListStore when adding route points from the
    context menu
* Sun May  2 2021 Michael Gorse <mgorse@suse.com>
- Update to version 40.1:
  + Fix a bug where unfavoring a place made it unselectable until
    after a restart.
  + Use country code attribute from GraphHopper/Photon geocode
    results to improve accuracy of address formatting among others.
  + Updated translations.
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Updated appdata screenshots.
  + Updated POI defintions for OSM editing.
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Made place bubble adaptive for use on phones.
  + Show native name of places in addition to translated one.
  + Avoid building some Flatpak dependencies which are now in the
    SDK.
  + Fix a bug resulting in writing a broken last view position on
    exit in some circumstances.
  + Fix a bug preventing wrapping around at the date line with dark
    tiles.
  + Increased width of layers thumbnails to avoid empty margins in
    some translations.
  + Update copyright year.
  + Updated translations.
* Mon Feb 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Place bubbles redesign with larger thumbnails, tidy list view,
    and summaries from Wikipedia when available in OSM.
  + More adapative UI fixes (for the no-network display).
  + Restore zooming to bounding boxes in search results (for
    administrative areas, buildings, etc.).
  + List compatible form factors in appdata.
  + Don't display invalid URLs and also show error message for
    invalid URLs when editing POIs in OSM.
  + Show localized name in user's language in place bubbles when
    available in OSM.
  + Normalize tel: URIs to support the Calls app on Librem 5 and
    Pinephone (among others).
  + Improve handling of OpenStreetMap URLs (to address objects or
    coordinated) when pasting into the search bar.
  + Load file contents of shape layer files using async operations
    (parsing is still done synchronous due to limitations with
    GJS).
  + Require GJS 1.66 now, to enable newer ES features like coalesce
    and the safe navigation operators.
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
* Sat Feb 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.4:
  + Fix a bug resulting in writing a broken last view position on
    exit in some circumstances.
  + Fix a bug preventing wrapping around at the date line with dark
    tiles.
  + Fix a bug causing hanging in cases when dragging around route
    markers.
  + Updated translations.
* Sat Jan  9 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.3:
  + Fix a bug where place details gets lost after searching again
    for the same place.
  + Updated translations.
* Mon Dec 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add check section and run meson_test macro. Add
  pkgconfig(gweather-3.0) BuildRequires needed for tests to
  succeed.
- Stop packaging versionless so file to avoid rpmlint warning.
* Sat Nov 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Updated translations.
* Fri Oct  9 2020 dimstar@opensuse.org
- Update to version 3.38.1.1:
  + Fix a race-condition bug in search-as-you-type resulting in
    out-of-sync search results in some circumstances.
  + Fix updating missing details after editing a POI in
    OpenStreetMap.
* Fri Oct  9 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Show error message in popover when a search request has failed.
  + Fix exception on shutdown when unregistering DBus.
  + Fix "no network" display to fit on smaller screens.
  + Updated translations.
* Fri Oct  9 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Oct  9 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Revert the adaptive UI for the routing sidebar, as there has
    been reports of crashes in some cases (related to Clutter and
    libhandy under Wayland).
  + Allow editing negative elevations on OSM objects (values below
    sea level).
  + Display population in place bubbles using localized number
    format.
  + Update POI type definitions from iD for OSM editing.
- Drop pkgconfig(libhandy-1) BuildRequires: no longer used.
* Fri Oct  9 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Add additional icons for walking directions for the
    OpenTripPlanner transit plugin.
  + Make the "no network" display adaptive.
- Changes from version 3.37.90:
  + Improved keyboard navigation for routing entries.
  + Adaptive UI for routing sidebar.
- Changes from version 3.37.3:
  + Implement night mode.
  + Implement support for hybrid aerial map style.
  + Add F10 keyboard shortcut for the main menu.
  + Fix an issue where some search result gets the wrong level of
    name.
- Changes from version 3.37.2:
  + Fix "no network" dispay to fit better on smaller displays.
  + Add initial basic support for running unit tests on builds.
  + Enable sandboxing on the WebKit web view used in OpenStreetMap
    account setup.
  + Limit the number of fraction digits when displaying raw
    coordinates in place entries.
  + Restrict the user location accuracy circle to only show when
    all of it fits in the view (both horizontally and vertically)
    to avoid obscuring too much of the map view i.e. on very wide
    displays. Also lower the opacity of the circle to make it
    "stand out" less.
- Changes from version 3.37.1:
  + Adaptive UI for narrow screens.
  + Recognize contact:website and contact:phone OSM tags.
  + Fix link to sign up for an OpenStreetMap account for editing.
  + Public transit routing plugin for GoMetro (South Africa).
  + Add command line option to specify tile size when using --local
    with a local tile cache.
  + Use localized digits in more places.
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
* Thu Oct  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4.1:
  + Fix a race-condition bug in search-as-you-type resulting in
    out-of-sync search results in some circumstances.
* Sat Jul  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Fix an issue where some search result gets the wrong level of
    name.
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Don't reset query points when routing fails (e.g. no public
    transit provider is available) to allow switching mode with the
    same query.
  + Fix a bug not displaying tiles south of the equator when using
  - -local.
  + Allow entering DMS coordinates without comma between latitude
    and logitude parts.
  + Updated translations.
* Sat Mar 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Updated POI definitions for OpenStreetMap editing.
  + Fixed link to sign up for an OpenStreetMap account.
  + Removed ctrl+f1 shortcut from the help overlay, since this was
    removed from GTK.
  + Updated translations.
* Sat Mar  7 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updated translations.
* Sat Feb 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.35.92:
  + Updated translations.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Add additional category code for busses in the Opendata.ch
    plugin.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Move “Export as Image” to the hamburger menu.
  + Restructure context menu items for routing to allow changing
    start and destination points without resetting the query from
    the sidebar.
  + Allow more width for the favourites popover and search result
    popovers in the routing sidebar to better avoid clipping longer
    place names.
- Changes from version 3.35.3:
  + Avoid flickering when animating user location marker.
- Changes from version 3.35.2:
  + Added public transit routing plugins for Resrobot (national
    Swedish transit API) and opendata.ch (for Switzerland).
  + Avoid "overflowing" the sidebar when a public transit itinerary
    has a large number of parts (legs) by ellipsizing in the middle
    when showing them in the journeys overview.
  + Add command line option to always consider being online
    (--force-online) as a work-around for certain VPN and proxy
    networks not playing well with NetworkManager.
  + Set User-Agent HTTP header in places where it was missing.
- Changes from version 3.35.1:
  + Initial support for public trasit routing/journey planning
    using third-party service providers.
  + Add nightly app icon (currently not installed, awaiting support
    for dual installations).
  + Update default tile size when using local tiles.
  + Updated translations.
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Updated translations.
* Sat Nov 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Fix encoding of Wikipedia URLs in some cases.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Update tile size to 512 px when using --local option.
  + Updated translations.
* Tue Sep 10 2019 qkzhu@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Sat Sep  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.33.92:
  + Update OSM POI types.
  + Fix performance issue when there's lots of location updates.
  + Updated translations.
* Sat Aug 31 2019 mgorse@suse.com
- Update to version 3.33.91:
  + Updated translations.
  + Changes in version 3.33.90:
  + Fix bug going back to already selected place from the search
    result list.
  + Start immediatly at the last viewed location when app was
    closed last.
  + Remember the map type (street or aerial) from when the app
    was closed last.
  + Updated translations.
  + Changes in version 3.33.4:
  + Handle opening OpenStreetMap URLs pointing to either an
    object or bare coordinates by pasting it into the search entry
    and also as a program argument, in the same manner as with
    geo: URIs.
  + Updated translations.
  + Changes in version 3.33.3:
  + Auto-complete searches ("search-as-you-type") using
    GraphHopper geocoder / Photon.
  + Redesigned Send to-dialog with ability to copy and send
    locations in e-mails and better integration with Weather and
    Clocks.
  + Show clockwise roundabout icons for turn-by-turn routing in
    left-hand traffic countries and territories.
  + Update appdata screenshots with tile style.
  + Fix a crash when there's many contacts with addresses in
    an Evolution address book.
  + Updated translations.
  + Changes in version 3.33.2:
  + Accept additional formats when entering raw coordinates in
    the search entry (decimal lat/lon degrees format with literal
    ° symbol, and degrees, minutes, second format).
  + Updated translations.
  + Changes in version 3.33.1:
  + Stop using GtkOffscreenWindow (prerequisite for eventually
    porting to GTK 4).
  + Fix printing dialog not closing in some circumstances.
  + Add some missing appstream metadata.
  + Add tests validating appdata and desktop files.
  + Remove some unnessesary instructions in turn-by-turn route
    searches.
  + Updated translations.
* Wed May 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2.1:
  + Make the shape layer renderer use the tile size specified in
    the dynamic service file, fixing an issue with misaligned shape
    layer (GeoJSON, GPX, KML) rendering with the new 512 pixel
    tiles.
  + Updated translations.
* Mon May  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Remove some unnessesary instructions in turn-by-turn route
    searches.
  + Updated translations.
* Sun Mar 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated appdata screenshots (shown in i.e. GNOME Software).
  + Fix displaying the proper application name in i.e. the
    gnome-shell overview and the top bar menu since a regression
    earlier in the 3.31.x cycle.
  + Update POI type defintions and translations for OSM editing.
  + Updated translations.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Fix array parsing error when loading shape layers when running
    with newer GJS.
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Show live-updated thumbnails for the street/aerial layer
    switcher, instead of (outdated) hard-code thumbnails.
  + Fix a bug where the scrollbar in the favorites popover didn't
    show up.
  + Updated translations.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Fix keyboard shortcut for quitting that was broken since the
    application menu was moved to the headerbar.
  + Update GJS build dependency.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Fix loading contact's adresses with newer GJS.
  + Fix some array-related GJS deprecation warnings.
  + Updated translations.
- Changes from version 3.31.2:
  + Move app menu to the headerbar.
  + Fix a crash that occured sometimes when activating "What's
    here?" from the context menu.
  + Fix compiler warnings.
  + Updated translations.
- Changes from version 3.31.1:
  + Updated application icon.
  + Start all way zoomed out on first run.
  + Fix shape layer file chooser not showing up.
  + Updated translations.
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Fix loading contact's adresses with newer GJS.
  + Updated translations.
* Thu Nov  8 2018 bjorn.lie@gmail.com
- Update to version 3.30.2.1:
  + Fix version number in release tarball (3.30.2 was missing
    update of meson.build).
  + Updated translations.
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + overpass, placeBubble: Avoid use-after-free.
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix shape layer file chooser not showing up.
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Remove lang package from recommended package as it already
  supplements main package (same effect, it's redundant).
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Updated POI definitions and translations for OSM editing.
  + Updated translations.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 3.29.91:
  + Don't spin up CI environments for master and tags.
  + Updated translations.
* Mon Jul 30 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Add a Flatpak CI build/test job.
  + Updated translations.
* Sun Jul 22 2018 luc14n0@linuxmail.org
- Update to version 3.29.4:
  + Updated translations.
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Update to version 3.29.3:
  + Stop using notifications on top of the map view as it doesn't
    work on Wayland.
  + Add OARS tags.
  + Updated translations.
* Sun Jun  3 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Updated translations.
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 3.29.1:
  + Switch to build with Meson (also dropped support for building
    with Autotools).
  + Disable UI for switching between street and aerial view if the
    service definition lacks aerial tile definitions (allows using
    a tile server not supplying aerial tiles).
  + Enable selecting map markers using touch.
- Add meson BuildRequires and use meson macros following upstreams
  port.
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Enable selecting map markers on touch screens.
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Fix an accidentally untranslated string.
  + Updated translations.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Change license of two files to GPL 2 or later (as was the
    original intension and what the project as a whole is using).
  + Updated translations.
- Change license back to GPL-2.0-or-later: upstream fixed the
  issue.
* Fri Mar  9 2018 dimstar@opensuse.org
- Change license to GPL-3.0-or-later: the two files
  ./lib/maps-osm-oauth-proxy-call.[ch] pull the license from
  GPL-2.0-or-later to GPL-3.0-or-later.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated POI definitions for OpenStreetMap editing.
  + Fix a segmentation fault at exit.
  + Fix missing generated files and third-party licenses in the
    distributed release archive.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Use moder JS features (ES6), classes and arrow notation
    (=> () ) for binding anonymous functions.
  + Change default line with and color for layer lines in loaded
    layers to make them more visible.
  + Don't select text in place entries in the routing sidebar when
    auto-completing.
  + Bugfixes for keyboard navigation in search entry completion
    popover.
  + Add additional tooltips for buttons in the routing sidebar.
  + Decrease height of OSM login dialog.
  + Updated translations.
* Tue Jan  9 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Show thumnails from Wikipedia in the place bubbles when
    availability.
  + Make the place bubble popovers follow the map when the view
    scrolls (i.e. when using the keyboard shortcuts to scroll).
  + Move the zoom control buttons to the headerbar to mitigate an
    issue with Clutter and overlay GTK+ widgets on Wayland.
  + Adapt libgweather dependency to use gitlab.gnome.org for
    building Flatpaks.
  + Updated translations.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Show tile provider and OSM attribution in the About dialog.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Maps: the current Maps'
  web page location.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Fix:
  - Maps to be available as an option for "Open with another
    application" for geo shape layer files.
  - JS warnings about redundant function arguments and similar
    things.
  + Updated translations.
- Drop gnome-maps-is-translations.patch and
  gnome-maps-nb-translations.patch: fixed upstream.
- Drop %%glib2_gsettings_schema_requires macro since RPM file
  triggers take care of this function now.
* Wed Dec 27 2017 badshah400@gmail.com
- Update to version 3.27.1:
  + Use sidebar icon style for icons in the routing results.
  + Improve the look of route labels for public transit trips when
    using the dark theme.
  + Add --version command line option.
  + Fix network detection when running as a Flatpak.
  + Update appdata screenshots.
  + Show stored routes according to locale direction.
* Fri Dec 22 2017 zaitor@opensuse.org
- Add gnome-maps-is-translations.patch: Update Icelandic
  translations.
- Add gnome-maps-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Clean up spec, use modern macros.
- Add lang package Recommends.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 3.26.2:
  + Fix network detection when running as a Flatpak.
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Avoid a GTK+ warning on startup.
  + Export symbols from modules using var instead of const to
    comply with ES6 and avoid a warning on newer GJS versions.
  + Updated translations.
* Tue Oct  3 2017 jengelh@inai.de
- Update RPM groups.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Don't focus the search entry on start (prevents showing the
    on-screen keyboard at start on touch devices).
  + Make OSM edit and export image dialogs modal (fixes positioning
    on Wayland).
  + Update OSM POI definitions and translations.
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Fix loading layer files when running as Flatpak.
  + Don't allow adding more than one instance of address on OSM
    objects.
  + Updated translations.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Allow viewing and editing OSM editor notes when editing
    objects.
  + Updated translations.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Show feedback when no search results were found.
  + Update Flatpak manifest for build changes in geocode-glib.
  + Various bugfixes.
  + Updated translations.
- Drop no longer needed glib2_gsettings_schema_post(un),
  icon_theme_cache_post(un) and desktop_database_post(un) from
  post(un) handling, we have file-triggers to take care of this for
  us now.
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Added keyboard shortcuts for switching between street and
    aerial view.
  + Added keyboard shortcut for opening layer files.
  + Remember the last used mode of transportation for routing (also
    now default to walking on first run).
  + For transit results, don't reset previous list when no later or
    earlier alternatives are found.
  + Also print coordinates in debug printout from GeoClue.
  + Show and support editing for additional OpenStreetMap tags
    (religion and information on availability of toilets).
  + Updated translations.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Fix OpenStreetMap editing in Flatpaks (update librest build
    dependency).
  + Use localized format when showing distances.
  + Updated translations.
* Tue May 23 2017 firebird209@gmail.com
- Update to version 3.25.1:
  + Fix JSON formatting for Flatpak manifest.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Fix OpenStreetMap editing in Flatpaks (update librest build
    dependency).
  + Updated translations.
* Tue May  9 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Avoid a use-after-free crash in contact store.
  + Updated translations.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + Fix rendering of compacted route labels for transit routing.
  + Don't show the “Next” button when selecting POI types when
    editing OpenStreetMap objects.
  + Use HTTPS Wikipedia links.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Fix running when gnome-online-accounts isn't available.
  + Updated translations.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Fix rendering Wikipedia links to articles containing a colon.
  + Updated OpenStreetMap POI definitions for editing.
  + Handle application/geo+json mime type for GeoJSON layer files.
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Support for public transit routing (enabled when service
    definition contains a URL for an OpenTripPlanner server, or by
    debug environment variable).
  + Add a button to reverse a route.
  + Stop using "for in" loops to traverse arrays.
  + Fixes for ES6 (GJS 1.48).
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Updated translations.
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 3.23.4:
  + Removed usage of deprecated gtk_menu_popup() function.
  + Updated translations.
* Fri Dec 16 2016 sknorr@suse.com
- Improve package description.
* Tue Dec 13 2016 dimstar@opensuse.org
- Update to version 3.23.3:
  + Enable easy building as a flatpak from within GNOME Builder.
  + Updated translations.
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + Use Unicode in translatable strings.
  + Updated translations.
* Wed Nov  9 2016 dimstar@opensuse.org
- Update to version 3.23.1:
  + Fixed a typo and a formatting issue.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Handle a plain 00:00-24:00 opening hour specification as being
    "always open" for POIs.
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Added = accelerator for zoom-in.
  + Fix rendering of website links containing HTML markup
    characters.
  + Updated/added POI definitions for OpenStreetMap editing.
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fix bug where you could not type + or - in the searchbar.
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Download a service.json file to get tile server URI among other
    things.
  + Use GtkClutter for the attribution logo, to get transparency.
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + osmEditDialog: URI-escape tel: URIs when copying to the phone
    field.
  + printLayout: Change color of instructionWidget before printing.
  + Updated translations.
- Remove use of sed to fix errounus bump of libchamplain.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.20.3.1 (boo#995112):
  + Fix bug where you could not type + or - in the searchbar.
  + Fix horizontal wrapping of the map.
- Use sed to revert libchamplain version bump, upstream did not
  intend to bump.
* Thu Aug 25 2016 badshah400@gmail.com
- Update to version 3.20.3 (boo#995112):
  + Download a service.json file to get tile server URI among
    other things.
  + Use GtkClutter for the attribution logo, to get transparency.
* Sun Jul 31 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Change tile URIs to use Mapbox, through proxy.
  + Fix escaping of tel: URIs.
  + Adapt colors of instuction when printing routes.
  + Updated translations.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Bump dependencies on libchamplain and gjs.
  + Fix memory leak in osmEdit.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Fix marking of translatable strings.
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Rework geoclue interaction.
  + Ellipsize route instructions in print layout.
  + Add 'aeroway' type to OSM editing.
  + Make auto-complete accent insensitive.
  + Updated translations.
* Tue Mar  1 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Handle case when nothing was found when reverse geocoding
    through context menu.
  + Make sure we validate bounding boxes from geoJSON layer.
  + Add markers to route when printing.
  + Add via points to route when printing.
  + Add ability to add and edit addresses on OpenStreetMap.
  + Allow Maps to shrink more by not using a fixed width for the
    searchbar.
  + Add tooltip to icon next to route entry to help discoverbility
    of drag and drop re-oredering.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Added icon to toggle visibility of a shape layer.
  + Improve travel animations.
  + Add a scale ruler to the bottom left corner.
  + Include less information by default in map bubbles.
  + Add expandable area on map bubbles.
  + Add context menu item for adding location to OpenStreetMap.
  + Enable editting of opening hours on OpenStreetMap.
  + Add internet access tag to map bubbles.
  + Add ele altitude tag to map bubbles.
  + Add website to map bubbles.
  + Add phone nunber to map bubbles.
  + Add support for KML and GPX shape files.
  + Add support for printing a route with instructions.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Addded a keybinding help overlay (F1 to activate).
  + Fix zoom behaviour to be more aggresive.
  + Fix bug with cancel login in OpenStreetMap account dialog.
  + Add keyboard shortcut for going to current location
    (<Primary>L).
  + Fix layout of OpenStreetMap edit.
  + Fix bug that made it impossible to sign-in to OpenStreetMap if
    you first inputed the wrong credentials.
  + Fix drag-and-drop to be more acceptive and responsive.
  + Make sure we can export our markers to PNG.
  + Give user the choice of exporting markers or not.
  + Add GUI for loading and managing shape layers such as GeoJSON
    or in the future(?) KML.
  + Add roundabout support to route.
  + Use a regular GtkButton for marking favorites.
  + Updated translations.
* Sun Dec 20 2015 zaitor@opensuse.org
- Update to version 3.19.3:
  + Added export to image to context menu.
  + Added support for MultiPoint in GeoJSON.
  + Fixed bug in send-to-dialog when default browser has no icon.
  + Added support for MapBox simplestyle for GeoJSON.
  + Added support for editing locations in OpenStreetMap.
  + Updated translations.
- Add pkgconfig(rest-0.7) and pkgconfig(libxml-0.2) BuildRequires:
  New dependencies.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Fix GeoJSON filling of polygons in polygons.
  + Add simpler keyboard shortcuts for zoom.
  + Fix width of send-to dialog.
  + Add open with browser to send-to dialog that will open a
    location on OpenStreetMap web.
  + Handle the 'geo' URI scheme, this will allow us to handle geu:
    URIs in for instance the browser or in Polari.
  + Go to latest visited view on start up.
  + Updated translations.
- Changes from version 3.19.1:
  + Use new convenience library for GeoClue.
  + Add support for opening and displaying GeoJSON files.
  - https://en.wikipedia.org/wiki/GeoJSON
  - This is with help of the Mapbox geojson-vt javascript code
    found at: https://github.com/mapbox/geojson-vt
  + Updated translations.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix bugs in contact address lookup:
  - No more warnings if address has no street address.
  - Do not attempt to classify type of address if only one(1).
  + Make sure the bounding box of a geocoded places is valid before
    using.
  + Make sure send-to-dialog has usable width.
  + Updated translations.
* Sat Oct 10 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix bugs in zooming to a location or contact.
  + Fix styling of dialog header buttons.
  + Updated translations.
* Fri Sep 25 2015 zaitor@opensuse.org
- Update to version 3.18.0.1:
  + Fix bug that prevented Maps from launching.
  + Updated translations.
* Sun Sep 20 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Add --local switch to use local, offline, tiles from a
    structured directory.
  + Updated translations.
* Sun Aug 30 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Fix memory leaks in contacts handling.
  + Make sure car routes gets correct icon.
  + Updated translations.
* Sat Aug 22 2015 zaitor@opensuse.org
- Update to version 3.17.90.1:
  + Fix up search popup list.
  + Fix storing of transportation type of route.
  + Some bugfixes.
  + Updated translations.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Add new user-location icon.
  + Add directional user-location icon.
  + Show heading from Geoclue.
  + Do not animate on 'what is here?'.
  + Add support for Geo URI (RFC5870) in searchbar.
  + Add 'Copy Geo URI' context menu item.
  + Store and complete against recent routes.
  + Updated translations.
* Tue May 12 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Switch to template for more UI files.
  + Do not use intltool to translate GSettings schema.
  + Improve height of favorites popover.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix favorite popover size.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide a symbolic variant of the app icon.
  + Add new appdata screenshots.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Fix links for wikipedia.
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Use proper location instead of nearest city when sending
    location to Weather.
  + Fix bug with layer ordering that made it impossible to drag
    routes under accuracy circle.
  + Fix Clutter/GTK event re-entrant dead-lock on right click.
  + Updated translations.
* Sun Mar  1 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Fix leak in libmaps geocode.
  + Only add contacts that properly geocode to a location.
  + Fix bug that fetched a route twice for each request.
  + Fix event handling of clutter and GTK+ that lead to deadlock
    and freeze when you clicked the map.
  + Fix being able to mark search results as favorites.
  + Updated translations.
- Add pkgconfig(geoclue-2.0) BuildRequires: new dependency.
- Drop gnome-maps-NULL-sentinels.patch: fixed upstream.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90.2:
  + Fix build for clang/FreeBSD.
- Add gnome-maps-NULL-sentinels.patch: Fix missing NULL sentinels.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Install Maps C library into pkglibdir.
- Changes from version 3.15.90:
  + Show notification with link to privacy panel when location
    service is off.
  + Only show user location marker when location service is
    enabled.
  + Added a 'show-location' activation action, to show contacts in
    Maps.
  + Add contacts with geocodable addresses to the placeStore to
    allow completion in search.
  + Updated translations.
- Add pkgconfig(folks), pkgconfig(gee-0.8),
  pkgconfig(champlain-0.12) and pkgconfig(geocode-glib-1.0)
  BuildRequires: new dependencies.
* Fri Jan 16 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Smarter filtering in favorites menu.
  + Make opening hours translatable.
  + Convert to "package.js" application convention.
  + Add runtime dependency checks.
  + Refresh place meta data if stale.
  + Switch to new full color mark-location icon.
  + Zoom in and center map marker on double-click.
  + Updated translations.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 3.15.3.1:
  + Use search popover for completion.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Remove 'I am here' menu item from context menu.
  + Improve geoclue interaction somewhat.
  + Use Overpass API to add meta data to map bubbles.
  + Use HTTPS for GraphHopper service.
  + Add drag-n-drop to route entries.
  + Add check-in possibility to user location bubble
    (Facebook/Foursquare).
  + Updated translations.
* Sun Nov 30 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + Use proper GtkButtons for zoom control.
  + Add a 'No network view' to show when Maps is disconnected.
  + Added <Ctrl-f> accelrator to grab focus on search.
  + Added <Ctrl-d> accelerator to open route planner.
  + Added route button to MapBubble.
  + Enable panning by keyboard.
  + Add extra info to search result bubbles:
  - Popuplation
  - Wikipedia
  - Opening hours
  - Wheelchair accesability.
  + Improve the UI of the search result popover.
  + Add 'share' button to MapBubbles to allow user to
    share location to weather and clocks.
  + Add favorites handling to main window and MapBubbles.
  + Updated translations.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1.2:
  + Fix typo in icon name.
- Changes from version 3.14.1.1:
  + Use symbolic icons in instruction list. This fixes scaling
    issues on Hi-DPI and recoloring.
  + Updated translations.
* Fri Oct 10 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix issue where icons did not recolor on dark theme.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: enable detection of
  typelib()-Requires (bnc#897852).
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Improve sidebar alignments.
  + Fix default transportation mode bug.
  + Make coordinates in entry editable.
  + Do not forget route on sidebar hide.
  + Hopefully a fix for non-consistent build error.
  + Hopefully a fix for elusive segfault in sidebar.
  + Default focus on entry in sidebar reveal.
  + Fix for theme problem with instruction list.
  + Updated translations.
- Drop gnome-maps-parallelbuild.patch: fixed upstream.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Add high contrast icon of logo.
  + Use kinetic scroll mode.
  + Set correct desktopId for geoclue.
  + Send correct argv/argc to GApplication.
  + Fix bug where selecting from completion nullified placeEntry.
  + Add content rich map markers and map bubbles based on
    GtkPopover.
  + Add tooltips to GtkHeaderButtons.
  + Add support for via points in routing.
  + Updated translations.
* Sun Aug 24 2014 dimstar@opensuse.org
- Add gnome-maps-parallelbuild.patch: Fix rules used to make
  parallel build more reliable (bgo#734507).
* Sat Jul 19 2014 zaitor@opensuse.org
- Update to version 3.13.4:
  + Fix sidebar margin for LTR.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Added sidebar for route searching.
  + Fix styling of popovers.
  + Fix cleanup for make dist.
  + Fixup AppData file.
- Changes from version 3.12.2:
  + New popover based UI for layers menu.
  + Added in app notifications.
  + Make clicking the map grab focus to be able to remove on-screen
    keyboard on tablets.
  + Maps now DBus activatable.
  + Handle GeoClue2 service not available.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Added padding to main window search entry.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Enable keyboard navigation in search results popover.
  + Make clicking the map grab focus and dismiss on screen
    keyboard.
  + Updated translations.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Update about dialog.
  + Fix a bug that could put Maps in an endless loop.
  + Fix a 'make distcheck' bug.
  + Use markup for superscripts.
  + Updated translations.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Make the search results show in a GtkPopover.
  + Fix a bug where search result spinner sometimes wouldn't be
    centered.
  + Updated translations.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 3.11.5.1:
  + Fix some compiler warnings.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Much smoother goto animations.
  + Avoid a redundant zoom-out at end of goto animations by making
    use of new geocode-glib and libchamplain API.
  + Make Maps work against geoclue 2.1.x and latest gtk+.
  + If accuracy area is less than 1, show 'exact' instead of
    '0 km2'.
  + Explicitly specify desired accuracy level to geoclue.
  + Update website URL in AppData file.
  + Make gnome-maps executable a real binary.
  + Update recent added time on re-visits.
  + Fix a compiler warning.
  + Updated translations.
- Add pkgconfig(gobject-introspection-1.0) and pkgcofig(gio-2.0)
  BuildRequires: new dependencies.
* Fri Jan 17 2014 zaitor@opensuse.org
- Update to version 3.11.4.1:
  + Provide completion for search based on recently used search
    results.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Set saner minimum zoom level on the map view.
  + Updated translations.
* Thu Nov 21 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Clearer dconf key descriptions.
  + Use Unicode quotation marks and apostrophes.
  + Updated translations.
* Wed Nov 13 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix issue of Maps not updating user's location at first launch.
  + Fix the awkward looking and slow goto animation and make it
    linear and fast.
  + Don't point to inexistent directories in gnome-maps script.
  + Mark two forgotten strings for translation.
  + Updated translations.
* Sun Sep 15 2013 dimstar@opensuse.org
- Recommend dbus(org.freedesktop.GeoClue2): having the GeoClue2
  service avaialble allows for geolocation and automatic
  positioning (accuracy depending on available hardware and
  connection).
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Provide an AppData file for GNOME software center.
  + Improved search results popup:
  - Add a scroll window to not fill screen with results.
  - Show place icons when available for user to be able to
    differentiate between results.
  - Show a spinner when search is on going.
  - Show matched part of results in bold fonts.
  + Add a context menu with two options:
  - "What's here?": Finds the name of the place at cursor
    position.
  - "I'm here": Corrects/changes Maps' idea of where user is
    currently.
  + Gracefully handle markup in search results.
  + Fix build against latest gnome-common.
  + Updated translations.
* Fri Aug 23 2013 zaitor@opensuse.org
- Update to version 3.9.90.2:
  + Drop usage of Geoclue library as its going to be dropped in
    Geoclue 1.99.2.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90.1:
  + Brown paperbag release for also updating version in
    configure/build.
- Changes from version 3.9.90:
  + Search results are shown in a popup menu rather than as markers
    on the map.
  + Draw window decorations client-side, following the new GNOME3
    trend.
  + The user location button is no longer a toggle.
  + Add buttons and key bindings for zooming in and out.
  + Updated translations.
* Fri Aug  2 2013 cfarrell@suse.com
- License update: GPL-2.0+: As libgd is compiled with the rest of
  the GPL-2.0+ files, the resulting binary is GPL-2.0+ not
  LGPL-2.1.
* Tue May 14 2013 dimstar@opensuse.org
- Initial package, version 3.9.5.
